+++
title = "Taxonomy weights and page weight 3"
tags = ["weight", "taxonomy-weight", "manual", "tags", "page-weight", "categories"]
draft = false
categories_weight = 999
tags_weight = 111
weight = 77
+++

If you want to specify page weight along with taxonomy weights, **and**
if you do not use the `:page` keyword before the weight value, the
page weight **must** be specified as the very first weight, even when
you specify the weights separately on each line.
